@@ -8,7 +8,7 @@ use nom::{
         complete::{alphanumeric0, newline},
         streaming::line_ending,
     },
-    combinator::{eof, map, map_parser, opt},
+    combinator::{eof, map, map_parser, map_res, opt, rest},
     multi::{many0, many_till},
     sequence::{delimited, preceded, separated_pair, terminated, tuple},
     IResult,
